@@ -9,7 +9,7 @@
 #' 
 #' Creates new AdRule objects.
 #' 
-#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201811/AdRuleService#createAdRules}{Google Documentation for createAdRules}
+#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201905/AdRuleService#createAdRules}{Google Documentation for createAdRules}
 #' 
 #' @param request_data a \code{list} or \code{data.frame} of data elements
 #' to be formatted for a SOAP
@@ -22,6 +22,7 @@
 #' \dontrun{
 #'  res <- dfp_createAdRules(request_data)
 #' }
+
 #' @export
 dfp_createAdRules <- function(request_data, as_df=TRUE, verbose=FALSE){
   request_body <- form_request_body(service='AdRuleService', root_name='createAdRules', data=request_data)
@@ -40,7 +41,7 @@ dfp_createAdRules <- function(request_data, as_df=TRUE, verbose=FALSE){
 #'   \item{status}
 #' }
 #' 
-#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201811/AdRuleService#getAdRulesByStatement}{Google Documentation for getAdRulesByStatement}
+#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201905/AdRuleService#getAdRulesByStatement}{Google Documentation for getAdRulesByStatement}
 #' 
 #' @param request_data a \code{list} or \code{data.frame} of data elements
 #' to be formatted for a SOAP
@@ -54,6 +55,7 @@ dfp_createAdRules <- function(request_data, as_df=TRUE, verbose=FALSE){
 #'  dat <- list(filterStatement=list('query'="WHERE status='ACTIVE'")) 
 #'  res <- dfp_getAdRulesByStatement(dat)
 #' }
+
 #' @export
 dfp_getAdRulesByStatement <- function(request_data, as_df=TRUE, verbose=FALSE){
   request_body <- form_request_body(service='AdRuleService', root_name='getAdRulesByStatement', data=request_data)
@@ -62,11 +64,38 @@ dfp_getAdRulesByStatement <- function(request_data, as_df=TRUE, verbose=FALSE){
   return(result)
 }
 #' 
+#' getAdSpotsByStatement
+#' 
+#' Gets a AdSpotPage of AdSpot objects that satisfy the given \{@@link Statement query\}.
+#' 
+#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201905/AdRuleService#getAdSpotsByStatement}{Google Documentation for getAdSpotsByStatement}
+#' 
+#' @param request_data a \code{list} or \code{data.frame} of data elements
+#' to be formatted for a SOAP
+#' request (XML format, but passed as character string)
+#' @param as_df a boolean indicating whether to attempt to parse the result into
+#' a \code{data.frame}
+#' @param verbose a boolean indicating whether to print the service URL and POSTed XML
+#' @return a \code{data.frame} or \code{list} containing all the elements of a getAdSpotsByStatementResponse 
+#' @examples
+#' \dontrun{
+#'  dat <- list(filterStatement=list('query'="WHERE status='ACTIVE'")) 
+#'  res <- dfp_getAdSpotsByStatement(dat)
+#' }
+
+#' @export
+dfp_getAdSpotsByStatement <- function(request_data, as_df=TRUE, verbose=FALSE){
+  request_body <- form_request_body(service='AdRuleService', root_name='getAdSpotsByStatement', data=request_data)
+  httr_response <- execute_soap_request(request_body=request_body, verbose=verbose)
+  result <- parse_soap_response(httr_response=httr_response, resp_element='getAdSpotsByStatementResponse', as_df=as_df)
+  return(result)
+}
+#' 
 #' performAdRuleAction
 #' 
 #' Performs actions on AdRule objects that match the given Statement query.
 #' 
-#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201811/AdRuleService#performAdRuleAction}{Google Documentation for performAdRuleAction}
+#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201905/AdRuleService#performAdRuleAction}{Google Documentation for performAdRuleAction}
 #' 
 #' @param request_data a \code{list} or \code{data.frame} of data elements
 #' to be formatted for a SOAP
@@ -79,6 +108,7 @@ dfp_getAdRulesByStatement <- function(request_data, as_df=TRUE, verbose=FALSE){
 #' \dontrun{
 #'  res <- dfp_performAdRuleAction(request_data)
 #' }
+
 #' @export
 dfp_performAdRuleAction <- function(request_data, as_df=TRUE, verbose=FALSE){
   request_body <- form_request_body(service='AdRuleService', root_name='performAdRuleAction', data=request_data)
@@ -91,7 +121,7 @@ dfp_performAdRuleAction <- function(request_data, as_df=TRUE, verbose=FALSE){
 #' 
 #' Updates the specified AdRule objects.
 #' 
-#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201811/AdRuleService#updateAdRules}{Google Documentation for updateAdRules}
+#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201905/AdRuleService#updateAdRules}{Google Documentation for updateAdRules}
 #' 
 #' @param request_data a \code{list} or \code{data.frame} of data elements
 #' to be formatted for a SOAP
@@ -104,6 +134,7 @@ dfp_performAdRuleAction <- function(request_data, as_df=TRUE, verbose=FALSE){
 #' \dontrun{
 #'  res <- dfp_updateAdRules(request_data)
 #' }
+
 #' @export
 dfp_updateAdRules <- function(request_data, as_df=TRUE, verbose=FALSE){
   request_body <- form_request_body(service='AdRuleService', root_name='updateAdRules', data=request_data)
