@@ -33,6 +33,7 @@
 #'   \item{Time_Zone}
 #'   \item{Proposal_Terms_And_Conditions}
 #'   \item{Change_History}
+#'   \item{ad_category}
 #' }
 #'
 #' Visit the See Also section below to proceed to Google and view columns in each of these tables.
@@ -41,7 +42,7 @@
 #' 
 #' Retrieves rows of data that satisfy the given Statement query from the system.
 #' 
-#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201811/PublisherQueryLanguageService#select}{Google Documentation for select}
+#' @seealso \href{https://developers.google.com/ad-manager/api/reference/v201905/PublisherQueryLanguageService#select}{Google Documentation for select}
 #' 
 #' @param request_data a \code{list} or \code{data.frame} of data elements
 #' to be formatted for a SOAP
@@ -64,12 +65,13 @@
 #'              WHERE CountryCode='US' AND (TYPE='STATE' OR TYPE='COUNTY')"))
 #'  us_geos <- dfp_select(request_data)
 #' }
+
 #' @export
 dfp_select <- function(request_data, verbose=FALSE){
   request_body <- form_request_body(service='PublisherQueryLanguageService', root_name='select', data=request_data)
   httr_response <- execute_soap_request(request_body=request_body, verbose=verbose)
   result <- parse_soap_response(httr_response=httr_response, resp_element='selectResponse', as_df=FALSE)
-  result <- dfp_select_parse(result[[1]])
+  result <- dfp_select_parse(result)
   return(result)
 }
 #' 
