@@ -398,5 +398,51 @@ service_map <- list(
       'ReconciliationLineItemReportService',
       'ReconciliationReportService', 'ReportService',
       'SuggestedAdUnitService', 'TeamService', 'UserService',
-      'UserTeamAssociationService', 'WorkflowRequestService')
+      'UserTeamAssociationService', 'WorkflowRequestService'),
+  'v201902'=
+    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+     'AdjustmentService', 'AdRuleService', 'AudienceSegmentService',
+     'BaseRateService', 'CdnConfigurationService', 'CmsMetadataService',
+     'CompanyService', 'ContactService', 'ContentBundleService',
+     'ContentService', 'CreativeService', 'CreativeSetService',
+     'CreativeTemplateService', 'CreativeWrapperService',
+     'CustomFieldService', 'CustomTargetingService',
+     'DaiAuthenticationKeyService', 'ExchangeRateService',
+     'ForecastService', 'InventoryService', 'LabelService',
+     'LineItemCreativeAssociationService', 'LineItemService',
+     'LineItemTemplateService', 'LiveStreamEventService',
+     'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+     'OrderService', 'PackageService', 'PlacementService',
+     'PremiumRateService', 'ProductService', 'ProductPackageService',
+     'ProductPackageItemService', 'ProductTemplateService',
+     'ProposalLineItemService', 'ProposalService',
+     'PublisherQueryLanguageService', 'RateCardService',
+     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+     'ReconciliationLineItemReportService',
+     'ReconciliationReportService', 'ReportService',
+     'SuggestedAdUnitService', 'TeamService', 'UserService',
+     'UserTeamAssociationService', 'WorkflowRequestService'),
+  'v201905'=
+    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+     'AdjustmentService', 'AdRuleService', 'AudienceSegmentService',
+     'BaseRateService', 'CdnConfigurationService', 'CmsMetadataService',
+     'CompanyService', 'ContactService', 'ContentBundleService',
+     'ContentService', 'CreativeService', 'CreativeSetService',
+     'CreativeTemplateService', 'CreativeWrapperService',
+     'CustomFieldService', 'CustomTargetingService',
+     'DaiAuthenticationKeyService', 'ExchangeRateService',
+     'ForecastService', 'InventoryService', 'LabelService',
+     'LineItemCreativeAssociationService', 'LineItemService',
+     'LineItemTemplateService', 'LiveStreamEventService',
+     'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+     'OrderService', 'PackageService', 'PlacementService',
+     'PremiumRateService', 'ProductService', 'ProductPackageService',
+     'ProductPackageItemService', 'ProductTemplateService',
+     'ProposalLineItemService', 'ProposalService',
+     'PublisherQueryLanguageService', 'RateCardService',
+     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+     'ReconciliationLineItemReportService',
+     'ReconciliationReportService', 'ReportService',
+     'SuggestedAdUnitService', 'TeamService', 'TargetingPresetService',
+     'UserService', 'UserTeamAssociationService', 'WorkflowRequestService')  
 )
