@@ -248,20 +248,20 @@ dfp_full_report_wrapper <- function(request_data,
   
   # continually check status until complete
   counter <- 0
-  while(dfp_getReportJobStatus_result[[1]] != 'COMPLETED' & counter < max_tries){
+  while(dfp_getReportJobStatus_result != 'COMPLETED' & counter < max_tries){
     dfp_getReportJobStatus_result <- dfp_getReportJobStatus(status_request_data, as_df=FALSE)
-    Sys.sleep(3)
+    Sys.sleep(check_interval)
     counter <- counter + 1
   }  
   
-  stopifnot(dfp_getReportJobStatus_result[[1]] == 'COMPLETED')
+  stopifnot(dfp_getReportJobStatus_result == 'COMPLETED')
   
   url_request_data <- list(reportJobId=report_job_id, exportFormat='CSV_DUMP')
   dfp_getReportDownloadURL_result <- dfp_getReportDownloadURL(url_request_data, as_df=FALSE)
   if(verbose){
     print(dfp_getReportDownloadURL_result)
   }
-  report_dat <- dfp_report_url_to_dataframe(report_url=dfp_getReportDownloadURL_result[[1]])
+  report_dat <- dfp_report_url_to_dataframe(report_url=dfp_getReportDownloadURL_result)
   
   return(report_dat)
 }
@@ -283,7 +283,7 @@ dfp_full_report_wrapper <- function(request_data,
 #' @export
 dfp_select_parse <- function(result){
   these_names <- unlist(result[grepl('columnTypes', names(result))], 
-                        use.names = F)
+                        use.names = FALSE)
   result_parsed <- map_df(result[grepl('rows', names(result))], 
                       .f=function(x){
                         x <- lapply(x, FUN=function(x){x$value})
