@@ -33,27 +33,20 @@ dfp_createOrders_result <- dfp_createOrders(request_data)
 options(rdfp.network_code = rdfp_options$network_code)
 
 test_that("dfp_createOrders", {
-
   expect_is(dfp_createOrders_result, 'data.frame')
   expect_true(all(c('id', 'name', 'notes', 'advertiserId', 
                     'traffickerId', 'isProgrammatic') %in% names(dfp_createOrders_result)))
-
 })
 
 test_that("dfp_getOrdersByStatement", {
-
    options(rdfp.network_code = rdfp_options$test_network_code)
    request_data <- list('filterStatement'=list('query'="WHERE name LIKE 'Test%'"))
-
    dfp_getOrdersByStatement_result <- dfp_getOrdersByStatement(request_data)
-
    expect_is(dfp_getOrdersByStatement_result, "data.frame")
    options(rdfp.network_code = rdfp_options$network_code)
-
 })
 
 test_that("dfp_updateOrders", {
-  
   options(rdfp.network_code = rdfp_options$test_network_code)
   request_data <- list(list(id=dfp_createOrders_result$id, 
                             name=paste0('TestOrder2'), 
@@ -77,21 +70,17 @@ test_that("dfp_updateOrders", {
   expect_is(dfp_updateOrders_result, 'data.frame')
   expect_true(all(c('id', 'name', 'notes', 'advertiserId', 
                     'traffickerId', 'isProgrammatic') %in% names(dfp_updateOrders_result)))
-  
   options(rdfp.network_code = rdfp_options$network_code)
-  
 })
 
 test_that("dfp_performOrderAction", {
-  
   options(rdfp.network_code = rdfp_options$test_network_code)
   request_data <- list(orderAction='DeleteOrders',
                        filterStatement=list('query'=paste0("WHERE name like 'Test%'")))
-  
-  dfp_performOrderAction_result <- dfp_performOrderAction(request_data, as_df=FALSE)
-  expect_is(dfp_performOrderAction_result, "list")
-  expect_length(dfp_performOrderAction_result, 1)
-  expect_named(dfp_performOrderAction_result[[1]], c("numChanges"))  
+  dfp_performOrderAction_result <- dfp_performOrderAction(request_data)
+  expect_is(dfp_performOrderAction_result, "data.frame")
+  expect_true(all(c('numChanges') %in% names(dfp_performOrderAction_result)))
+  expect_equal(dfp_performOrderAction_result$numChanges, 1)
   
   # check that action worked
   request_data <- list('filterStatement'=
@@ -100,7 +89,6 @@ test_that("dfp_performOrderAction", {
   dfp_getLabelsByStatement_result <- dfp_getLabelsByStatement(request_data)
   expect_is(dfp_getLabelsByStatement_result, "data.frame")
   expect_equal(nrow(dfp_getLabelsByStatement_result), 0)
-  
   options(rdfp.network_code = rdfp_options$network_code)
 })
 
